@@ -7,13 +7,14 @@ from .utils import (
     get_dates,
     get_holiday_detail,
     get_holidays,
+    get_solar_terms,
     get_workdays,
     is_holiday,
     is_in_lieu,
     is_workday,
 )
 
-__version__ = "1.6.0"
+__version__ = "1.7.1"
 __all__ = [
     "Holiday",
     "holidays",
@@ -23,6 +24,7 @@ __all__ = [
     "is_in_lieu",
     "is_workday",
     "get_holiday_detail",
+    "get_solar_terms",
     "get_dates",
     "get_holidays",
     "get_workdays",
